@@ -71,10 +71,9 @@ GeomCustomAnn <- ggproto("GeomCustomAnn", Geom,
   draw_panel = function(data, panel_params, coord, grob, xmin, xmax,
                         ymin, ymax) {
     if (!inherits(coord, "CoordCartesian")) {
-      stop("annotation_custom only works with Cartesian coordinates",
-        call. = FALSE)
+      abort("annotation_custom only works with Cartesian coordinates")
     }
-    corners <- data.frame(x = c(xmin, xmax), y = c(ymin, ymax))
+    corners <- new_data_frame(list(x = c(xmin, xmax), y = c(ymin, ymax)), n = 2)
     data <- coord$transform(corners, panel_params)
 
     x_rng <- range(data$x, na.rm = TRUE)
